Group.chat() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Group.chat()

Group.chat(**kwargs) → Chat

  Shortcut for creating a group chat.

  Parameters

    **kwargs – Any argument accepted by `Chat` can be used, including chat_id and nickname. Specifying the latter two will simply override the defaults.

  See also

  The basic functionality is provided in the `Chat` element, which can be used on its own.

  Returns

    A chat element in which the default for the chat id is set to the group id and the default for the nickname is set to each member’s role.

  Return type

    Chat